@@ -15,7 +15,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-class eclass:
+
+class Eclass:
     "eclass class."
 
     def __init__(self, name: str = None, url: str = None, teacher: str = None):
@@ -30,5 +31,6 @@ class eclass:
         self.name = name
         self.url = url
         self.teacher = teacher
+
     def __str__(self):
-        return self.url
\ No newline at end of file
+        return self.url
